==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/bg.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "activated" : "активиран",
    "deactivated" : "деактивиран",
    "created" : "създаден",
    "destroyed" : "унищожен",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Това е вашия резервен код. Моля, запишете го (или го принтирайте) защото по-късно няма да имате възможност да го видите.",
    "Save backup codes" : "Записване на резервния код",
    "Print backup codes" : "Принтиране на резервния код",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Резервен код е бил генериран. Използвани са {used} от {total} кода.",
    "Regenerate backup codes" : "Регенериране на резервния код",
    "If you regenerate backup codes, you automatically invalidate old codes." : "При регенерирането на резервния код, стария код автоматично бива анулиран.",
    "Generate backup codes" : "Генериране на резервни кодове",
    "An error occurred while generating your backup codes" : "Възникна грешка при генерирането на резервния код",
    "Nextcloud backup codes" : "Nextcloud резервни кодове",
    "You created two-factor backup codes for your account" : "Създадохте резервен код за двустепенното удостоверяване за вашия профил",
    "Second-factor backup codes" : "Резервен код за втората стъпка",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Включили сте двустепенното удостоверяването, но не сте създали резервен код. Моля, създайте резервен код, който да ползвате когато загубите достъп до устройството генериращо кода за втората стъпка в удостоверяването.",
    "Backup code" : "Резервен код",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Резервен код е бил генериран. Използвани са {{used}} от {{total}} кода."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/bg.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Това е вашия резервен код. Моля, запишете го (или го принтирайте) защото по-късно няма да имате възможност да го видите.",
    "Save backup codes" : "Записване на резервния код",
    "Print backup codes" : "Принтиране на резервния код",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Резервен код е бил генериран. Използвани са {used} от {total} кода.",
    "Regenerate backup codes" : "Регенериране на резервния код",
    "If you regenerate backup codes, you automatically invalidate old codes." : "При регенерирането на резервния код, стария код автоматично бива анулиран.",
    "Generate backup codes" : "Генериране на резервни кодове",
    "An error occurred while generating your backup codes" : "Възникна грешка при генерирането на резервния код",
    "Nextcloud backup codes" : "Nextcloud резервни кодове",
    "You created two-factor backup codes for your account" : "Създадохте резервен код за двустепенното удостоверяване за вашия профил",
    "Second-factor backup codes" : "Резервен код за втората стъпка",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Включили сте двустепенното удостоверяването, но не сте създали резервен код. Моля, създайте резервен код, който да ползвате когато загубите достъп до устройството генериращо кода за втората стъпка в удостоверяването.",
    "Backup code" : "Резервен код",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Резервен код е бил генериран. Използвани са {{used}} от {{total}} кода.",
    "activated" : "активиран",
    "deactivated" : "деактивиран",
    "created" : "създаден",
    "destroyed" : "унищожен"
},
"nplurals=2; plural=(n != 1);");
